@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 use Class::Accessor::Lite (
     new => 0,
@@ -37,11 +37,9 @@ sub new {
 
         timeout  => { isa => 'Int', default => 120 },
         debug    => { isa => 'Bool', optional => 1 },
-    );
+    )->with('NoRestricted')->with('Method');
     # Mouse::Util::apply_all_role leaks memory when takes 2 or more extensions.
     # so apply for each extension.
-    $rule->with('NoRestricted');
-    $rule->with('Method');
     my($class, $args) = $rule->validate(@_);
 
     if (delete $args->{debug}) {
